# Pull Request

## Description

<!-- Provide a brief description of the changes in this PR -->

## Type of Change

<!-- Mark the relevant option with an 'x' -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code refactoring
- [ ] Performance improvement
- [ ] Test updates

## Related Issue

<!-- Link to related issue(s) -->

Closes #<!-- issue number -->

## Changes Made

<!-- Describe the specific changes made in this PR -->

-
-
-

## Testing

<!-- Describe how you tested your changes -->

- [ ] I have run the test suite locally
- [ ] I have added/updated tests for new functionality
- [ ] All existing tests pass
- [ ] I have tested manually with Terminal

### Test Results

```text
Paste test output here if applicable
```

## Code Quality

<!-- Confirm the following -->

- [ ] Code follows the project's style guidelines
- [ ] I have run `ruff check` and fixed any issues
- [ ] I have updated documentation if needed
- [ ] My changes generate no new warnings
- [ ] I have added comments to complex code sections

## Checklist

- [ ] My code follows the code style of this project
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Additional Notes

<!-- Add any additional information that reviewers should know -->

## Screenshots (if applicable)

<!-- Add screenshots to help explain your changes -->
